@@ -1,7 +1,3 @@
-from __future__ import print_function
-
-
-from builtins import str
 def execute(self, inputs, outputs, gvm):
     import time
     
