@@ -23,12 +23,11 @@
 from gi.repository import GObject
 from gi.repository import Gtk
 from gi.repository import Gdk
-from future.utils import string_types
-from builtins import str
 import os
 from functools import partial
 
 from rafcon.core.states.library_state import LibraryState
+from rafcon.core.storage import storage
 from rafcon.gui.config import global_gui_config
 from rafcon.gui.runtime_config import global_runtime_config
 from rafcon.gui.controllers.utils.extended_controller import ExtendedController
@@ -37,7 +36,8 @@ from rafcon.gui.helpers.label import create_menu_item, append_sub_menu_to_parent
 from rafcon.gui.helpers.text_formatting import format_folder_name_human_readable
 import rafcon.gui.singleton as gui_singletons
 from rafcon.gui.utils import constants
-from rafcon.gui.utils.dialog import RAFCONButtonDialog
+from rafcon.gui.utils.dialog import RAFCONButtonDialog, RAFCONInputDialog
+from rafcon.gui.interface import open_folder
 from rafcon.utils import log
 
 logger = log.get_logger(__name__)
@@ -52,12 +52,22 @@ class LibraryTreeController(ExtendedController):
     TOOL_TIP_STORAGE_ID = 3
     LIB_KEY_STORAGE_ID = 4
 
-    def __init__(self, model, view):
+    def __init__(self, model, view, find_usages=False):
         assert isinstance(model, LibraryManagerModel)
         assert isinstance(view, Gtk.TreeView)
         ExtendedController.__init__(self, model, view)
         self.tree_store = Gtk.TreeStore(GObject.TYPE_STRING, GObject.TYPE_PYOBJECT, GObject.TYPE_STRING, GObject.TYPE_STRING, GObject.TYPE_STRING)
-        view.set_model(self.tree_store)
+        self.filter = self.tree_store.filter_new()
+        self.filter_value = ''
+        self.find_usages = find_usages
+
+        if find_usages:
+            self.filter.set_visible_func(self._library_usages_filter)
+            self.usages = None
+        else:
+            self.filter.set_visible_func(self._search_filter)
+
+        view.set_model(self.filter)
         view.set_tooltip_column(3)
 
         # Gtk TODO: solve via Gtk.TargetList? https://python-gtk-3-tutorial.readthedocs.io/en/latest/drag_and_drop.html
@@ -86,8 +96,12 @@ class LibraryTreeController(ExtendedController):
             menu.append(create_menu_item("Open", constants.BUTTON_OPEN, self.open_button_clicked))
             menu.append(create_menu_item("Open and run", constants.BUTTON_START, self.open_run_button_clicked))
             menu.append(Gtk.SeparatorMenuItem())
+            menu.append(create_menu_item("Rename library", constants.BUTTON_RENAME,
+                                         self.menu_item_rename_libraries_or_root_clicked))
             menu.append(create_menu_item("Remove library", constants.BUTTON_DEL,
                                          self.menu_item_remove_libraries_or_root_clicked))
+            menu.append(create_menu_item("Relocate library", constants.BUTTON_RELOCATE,
+                                         self.menu_item_relocate_libraries_or_root_clicked))
 
             sub_menu_item, sub_menu = append_sub_menu_to_parent_menu("Substitute as library", menu,
                                                                      constants.BUTTON_REFR)
@@ -104,15 +118,25 @@ class LibraryTreeController(ExtendedController):
                                              partial(self.substitute_as_template_clicked, keep_name=True)))
             sub_menu.append(create_menu_item("Take name from Library", constants.BUTTON_EXCHANGE,
                                              partial(self.substitute_as_template_clicked, keep_name=False)))
+
+            menu.append(create_menu_item("Find usages in libraries", constants.ICON_FIND_USAGES,
+                                         self.menu_item_find_usages_clicked))
+
         elif kind in ['library root', 'library tree']:
-            menu.append(create_menu_item("Add library root", constants.BUTTON_DEL,
+            menu.append(create_menu_item("Add library root", constants.BUTTON_NEW,
                                          self.menu_item_add_library_root_clicked))
             if kind == 'library root':
+                menu.append(create_menu_item("Rename library root", constants.BUTTON_RENAME,
+                                             self.menu_item_rename_libraries_or_root_clicked))
                 menu.append(create_menu_item("Remove library root", constants.BUTTON_DEL,
                                              self.menu_item_remove_libraries_or_root_clicked))
+                menu.append(create_menu_item("Relocate library root", constants.BUTTON_RELOCATE,
+                                             self.menu_item_relocate_libraries_or_root_clicked))
         elif kind == 'libraries':
             menu.append(create_menu_item("Remove libraries", constants.BUTTON_DEL,
                                          self.menu_item_remove_libraries_or_root_clicked))
+            menu.append(create_menu_item("Relocate libraries", constants.BUTTON_RELOCATE,
+                                         self.menu_item_relocate_libraries_or_root_clicked))
 
         return menu
 
@@ -129,6 +153,19 @@ class LibraryTreeController(ExtendedController):
                         self.view.expand_to_path(state_row_path)
                 return False
             self.open_button_clicked(None)
+
+            if self.find_usages:
+                state_machine_model = gui_singletons.state_machine_manager_model.get_selected_state_machine_model()
+                selected_states = []
+                queue = [state_machine_model.root_state]
+                while len(queue) > 0:
+                    state = queue.pop(0)
+                    if hasattr(state.state, 'lib_os_path') and state.state.library_path == self.filter_value[0] and state.state.library_name == self.filter_value[1]:
+                        selected_states.append(state)
+                    elif hasattr(state, 'states'):
+                        queue.extend(state.states.values())
+                state_machine_model.selection.set(selected_states)
+
             return True
 
         # Single right click
@@ -162,21 +199,17 @@ class LibraryTreeController(ExtendedController):
         self.update()
 
     def store_expansion_state(self):
-        # print("\n\n store of state machine {0} \n\n".format(self.__my_selected_sm_id))
         try:
             act_expansion_library = {}
             for library_path, library_row_iter in self.library_row_iter_dict_by_library_path.items():
                 library_row_path = self.tree_store.get_path(library_row_iter)
                 act_expansion_library[library_path] = self.view.row_expanded(library_row_path)
-                # if act_expansion_library[library_path]:
-                #     print(library_path)
             self.__expansion_state = act_expansion_library
         except TypeError:
             logger.warning("expansion state of library could not be stored")
 
     def redo_expansion_state(self):
         if self.__expansion_state:
-            # print("\n\n redo of state machine {0} \n\n".format(self.__my_selected_sm_id))
             try:
                 for library_path, library_row_expanded in self.__expansion_state.items():
                     library_row_iter = self.library_row_iter_dict_by_library_path[library_path]
@@ -184,9 +217,8 @@ class LibraryTreeController(ExtendedController):
                         library_row_path = self.tree_store.get_path(library_row_iter)
                         if library_row_expanded:
                             self.view.expand_to_path(library_row_path)
-                            # print(library_path)
             except (TypeError, KeyError):
-                logger.warning("expansion state of library tree could not be re-done")
+                pass
 
     def update(self):
         self.store_expansion_state()
@@ -227,7 +259,7 @@ class LibraryTreeController(ExtendedController):
                 return "[source]:\n{0}".format(tool_tip_with_only_sm_file_system_path_in)
 
         _library_key = self.convert_if_human_readable(library_key)
-        tool_tip = library_item if isinstance(library_item, string_types) else ''
+        tool_tip = library_item if isinstance(library_item, str) else ''
 
         if not tool_tip and parent is None:
             library_root_path = tool_tip = self.model.library_manager._library_root_paths.get(library_key, '')
@@ -281,23 +313,16 @@ class LibraryTreeController(ExtendedController):
         if state_row_path is not None:
             self.view.expand_to_path(state_row_path)
         self.view.scroll_to_cell(state_row_path, None)
-        self.view.get_selection().select_iter(library_state_row_iter)
+        # Important: do not use select_iter() here!
+        # The iters of the view (whose model is the TreeModelFilter) won't match
+        # the iters stored in library_row_iter_dict_by_library_path as those directly point to the TreeModel
+        self.view.get_selection().select_path(state_row_path)
         self.view.grab_focus()
 
     def select_library_tree_element_of_library_state_model(self, state_m):
         lib_tree_path = os.path.join(state_m.state.library_path, state_m.state.library_name)
         self.select_library_tree_element_of_lib_tree_path(lib_tree_path)
 
-    def select_open_state_machine_of_selected_library_element(self):
-        """Select respective state machine of selected library in state machine manager if already open """
-        (model, row_path) = self.view.get_selection().get_selected()
-        if row_path:
-            physical_library_path = model[row_path][self.ITEM_STORAGE_ID]
-            smm = gui_singletons.state_machine_manager_model.state_machine_manager
-            sm = smm.get_open_state_machine_of_file_system_path(physical_library_path)
-            if sm:
-                gui_singletons.state_machine_manager_model.selected_state_machine_id = sm.state_machine_id
-
     def open_button_clicked(self, widget):
         try:
             self.open_library_as_state_machine()
@@ -314,7 +339,7 @@ class LibraryTreeController(ExtendedController):
         import rafcon.gui.helpers.state_machine as gui_helper_state_machine
         (model, row) = self.view.get_selection().get_selected()
         physical_library_path = model[row][self.ITEM_STORAGE_ID]
-        assert isinstance(physical_library_path, string_types)
+        assert isinstance(physical_library_path, str)
 
         logger.debug("Opening library as state-machine from path '{0}'".format(physical_library_path))
         state_machine = gui_helper_state_machine.open_state_machine(physical_library_path)
@@ -349,6 +374,51 @@ class LibraryTreeController(ExtendedController):
         global_config.save_configuration()
         self.model.library_manager.refresh_libraries()
 
+    def menu_item_rename_libraries_or_root_clicked(self, menu_item):
+        """Rename library after request second confirmation"""
+
+        import rafcon.gui.helpers.state_machine as gui_helper_state_machine
+        menu_item_text = self.get_menu_item_text(menu_item)
+        logger.info("Rename item '{0}' pressed.".format(menu_item_text))
+        model, path = self.view.get_selection().get_selected()
+        if path:
+            tree_m_row = self.filter[path]
+            library_os_path, library_path, library_name, item_key = self.extract_library_properties_from_selected_row()
+            library_file_system_path = library_os_path
+            if "root" in menu_item_text:
+                button_texts = [menu_item_text + "from tree and config", "Cancel"]
+                partial_message = "This will remove the library root from your configuration (config.yaml)."
+            else:
+                button_texts = [menu_item_text, "Cancel"]
+                partial_message = "This folder will be renamed on the hard drive! Do you really want to do that?"
+            message_string = "You have chosen to {2} with " \
+                             "\n\nlibrary tree path:   {0}" \
+                             "\n\nphysical path:        {1}\n\n\n" \
+                             "{3}" \
+                             "".format(os.path.join(self.convert_if_human_readable(tree_m_row[self.LIB_PATH_STORAGE_ID]), item_key),
+                                       library_file_system_path,
+                                       menu_item_text.lower(),
+                                       partial_message)
+            width = 8 * len("physical path:        " + library_file_system_path)
+            dialog = RAFCONInputDialog(message_string,
+                                       button_texts,
+                                       message_type=Gtk.MessageType.QUESTION,
+                                       parent=self.get_root_window(),
+                                       width=min(width, 1400))
+            dialog.set_entry_text(item_key)
+            response_id = dialog.run()
+            new_name = dialog.get_entry_text()
+            dialog.destroy()
+            parent_library_os_path = os.path.abspath(os.path.join(library_os_path, os.pardir))
+            new_library_os_path = os.path.join(parent_library_os_path, new_name)
+            if response_id == 1:
+                if "root" in menu_item_text:
+                    gui_helper_state_machine.rename_library_root(tree_m_row[self.LIB_KEY_STORAGE_ID], new_name, logger)
+                else:
+                    gui_helper_state_machine.rename_library(library_os_path, new_library_os_path, library_path, library_name, new_name, logger)
+            return True
+        return False
+
     def menu_item_remove_libraries_or_root_clicked(self, menu_item):
         """Removes library from hard drive after request second confirmation"""
 
@@ -358,9 +428,8 @@ class LibraryTreeController(ExtendedController):
         model, path = self.view.get_selection().get_selected()
         if path:
             # Second confirmation to delete library
-            tree_m_row = self.tree_store[path]
+            tree_m_row = self.filter[path]
             library_os_path, library_path, library_name, item_key = self.extract_library_properties_from_selected_row()
-            # assert isinstance(tree_m_row[self.ITEM_STORAGE_ID], str)
             library_file_system_path = library_os_path
 
             if "root" in menu_item_text:
@@ -368,11 +437,11 @@ class LibraryTreeController(ExtendedController):
                 partial_message = "This will remove the library root from your configuration (config.yaml)."
             else:
                 button_texts = [menu_item_text, "Cancel"]
-                partial_message = "This folder will be removed from hard drive! You really wanna do that?"
+                partial_message = "This folder will be removed from your hard drive! Do you really want to do that?"
 
-            message_string = "You choose to {2} with " \
+            message_string = "You have chosen to {2} with " \
                              "\n\nlibrary tree path:   {0}" \
-                             "\n\nphysical path:        {1}.\n\n\n"\
+                             "\n\nphysical path:        {1}\n\n\n" \
                              "{3}" \
                              "".format(os.path.join(self.convert_if_human_readable(tree_m_row[self.LIB_PATH_STORAGE_ID]),
                                                     item_key),
@@ -411,6 +480,38 @@ class LibraryTreeController(ExtendedController):
             return True
         return False
 
+    def menu_item_relocate_libraries_or_root_clicked(self, menu_item):
+        """Relocate library after request second confirmation"""
+
+        import rafcon.gui.helpers.state_machine as gui_helper_state_machine
+        menu_item_text = self.get_menu_item_text(menu_item)
+        model, path = self.view.get_selection().get_selected()
+        if path:
+            tree_m_row = self.filter[path]
+            library_os_path, library_path, library_name, item_key = self.extract_library_properties_from_selected_row()
+            new_directory = open_folder('Select the new directory')
+            if new_directory:
+                if 'root' in menu_item_text:
+                    gui_helper_state_machine.relocate_library_root(tree_m_row[self.LIB_KEY_STORAGE_ID], new_directory, logger)
+                elif 'libraries' in menu_item_text:
+                    gui_helper_state_machine.relocate_libraries(library_os_path.replace('[source]:\n', ''), item_key, new_directory, logger)
+                else:
+                    gui_helper_state_machine.relocate_library(library_os_path, library_path, library_name, new_directory, logger)
+            return True
+        return False
+
+    def menu_item_find_usages_clicked(self, widget):
+        library_os_path, library_path, library_name, item_key = self.extract_library_properties_from_selected_row()
+        library_usages_controller = gui_singletons.main_window_controller.get_controller('library_usages_controller')
+        library_usages_controller.filter_value = [library_path, library_name]
+        usages = []
+        for root in library_usages_controller.model.library_manager.library_root_paths.values():
+            usages.extend(storage.find_library_dependencies_via_grep(root, library_usages_controller.filter_value[0], library_usages_controller.filter_value[1]))
+        library_usages_controller.usages = usages
+        library_usages_controller.filter.refilter()
+        library_usages_controller.view.expand_all()
+        gui_singletons.main_window_controller.upper_notebook.set_current_page(3)
+
     def substitute_as_library_clicked(self, widget, keep_name=True):
         import rafcon.gui.helpers.state_machine as gui_helper_state_machine
         gui_helper_state_machine.substitute_selected_state(self._get_selected_library_state(), as_template=False,
@@ -424,13 +525,15 @@ class LibraryTreeController(ExtendedController):
     def extract_library_properties_from_selected_row(self):
         """ Extracts properties library_os_path, library_path, library_name and tree_item_key from tree store row """
         (model, row) = self.view.get_selection().get_selected()
+        if row is None:
+            return None, None, None, None
         tree_item_key = model[row][self.ID_STORAGE_ID]
         library_item = model[row][self.ITEM_STORAGE_ID]
         library_path = model[row][self.LIB_PATH_STORAGE_ID]
         if isinstance(library_item, dict):  # sub-tree
             os_path = model[row][self.OS_PATH_STORAGE_ID]
             return os_path, None, None, tree_item_key  # relevant elements of sub-tree
-        assert isinstance(library_item, string_types)
+        assert isinstance(library_item, str)
         library_os_path = library_item
 
         library_name = library_os_path.split(os.path.sep)[-1]
@@ -452,3 +555,39 @@ class LibraryTreeController(ExtendedController):
                                        self.convert_if_human_readable(str(library_path)) + "/" + str(item_key)))
         library_name = library_os_path.split(os.path.sep)[-1]
         return LibraryState(library_path, library_name, "0.1", format_folder_name_human_readable(library_name))
+
+    def _search_filter(self, model, iter, data):
+        if not self.filter_value or self.filter_value in model.get_value(iter, self.ID_STORAGE_ID).lower():
+            return True
+        else:
+            parent_iter = model.iter_parent(iter)
+            while parent_iter is not None:
+                if self.filter_value in model.get_value(parent_iter, self.ID_STORAGE_ID).lower():
+                    return True
+                parent_iter = model.iter_parent(parent_iter)
+            queue = [iter]
+            while len(queue) > 0:
+                node_iter = queue.pop(0)
+                if model.iter_has_child(node_iter):
+                    for i in range(model.iter_n_children(node_iter)):
+                        queue.append(model.iter_nth_child(node_iter, i))
+                if self.filter_value in model.get_value(node_iter, self.ID_STORAGE_ID).lower():
+                    self.view.expand_all()
+                    return True
+        return False
+
+    def _library_usages_filter(self, model, iter, data):
+        if self.filter_value:
+            if not model.iter_has_child(iter):
+                return model.get_value(iter, self.ITEM_STORAGE_ID) in self.usages
+            else:
+                queue = [iter]
+                while len(queue) > 0:
+                    node_iter = queue.pop(0)
+                    if model.iter_has_child(node_iter):
+                        for i in range(model.iter_n_children(node_iter)):
+                            queue.append(model.iter_nth_child(node_iter, i))
+                    else:
+                        if model.get_value(node_iter, self.ITEM_STORAGE_ID) in self.usages:
+                            return True
+        return False
\ No newline at end of file
