@@ -17,7 +17,6 @@
 
 """
 
-from builtins import object
 from gi.repository import Gtk
 from gi.repository import Gdk
 from gi.repository import GObject
@@ -105,6 +104,8 @@ class StateMachineRightClickMenu(object):
         add_sub_menu.append(create_menu_item("Scoped Variable", constants.BUTTON_ADD, self.on_add_scoped_variable,
                                              accel_code=shortcuts_dict['add_scoped_variable'][0],
                                              accel_group=accel_group))
+        menu.append(create_menu_item("Delete", constants.BUTTON_DEL, self.on_delete,
+                                     accel_code=shortcuts_dict['delete'][0], accel_group=accel_group))
         menu.append(Gtk.SeparatorMenuItem())
 
         self.insert_copy_cut_paste_in_menu(menu, shortcuts_dict, accel_group)
@@ -113,7 +114,6 @@ class StateMachineRightClickMenu(object):
         selection = gui_singletons.state_machine_manager_model.get_selected_state_machine_model().selection
         selected_state_m = selection.get_selected_state()
         all_m_list = gui_singletons.state_machine_manager_model.get_selected_state_machine_model().selection.get_all()
-        # logger.info("Element in selection: " + str(selected_state_m) + " : " + str([elem for elem in all_m_list]))
         if any([isinstance(elem, (AbstractStateModel, ScopedVariableModel)) for elem in all_m_list]) and \
                 all([isinstance(elem, (AbstractStateModel, ScopedVariableModel, TransitionModel, DataFlowModel))
                      for elem in all_m_list]) and \
@@ -150,8 +150,7 @@ class StateMachineRightClickMenu(object):
 
         # save state as but not for root state, therefore the user should use save state machine as
         if len(selection.states) == 1 and not selected_state_m.state.is_root_state:
-            save_as_sub_menu_item, save_as_sub_menu = append_sub_menu_to_parent_menu("Save state as", menu,
-                                                                                     constants.BUTTON_SAVE)
+            _, save_as_sub_menu = append_sub_menu_to_parent_menu("Save state as", menu, constants.BUTTON_SAVE)
             callback_function = partial(self.on_save_as_activate,
                                         save_as_function=gui_helper_state_machine.save_selected_state_as)
             save_as_sub_menu.append(create_menu_item("State machine", constants.BUTTON_SAVE,
@@ -170,9 +169,7 @@ class StateMachineRightClickMenu(object):
                                                                  callback_function,
                                                                  accel_code=None, accel_group=accel_group))
         else:
-            save_as_sub_menu_item, save_as_sub_menu = append_sub_menu_to_parent_menu("Save state machine as", menu,
-                                                                                     constants.BUTTON_SAVE)
-
+            _, save_as_sub_menu = append_sub_menu_to_parent_menu("Save state machine as", menu, constants.BUTTON_SAVE)
             callback_function = partial(self.on_save_as_activate,
                                         save_as_function=gui_helper_state_machine.save_state_machine_as)
             save_as_sub_menu.append(create_menu_item("State machine", constants.BUTTON_SAVE,
@@ -190,7 +187,12 @@ class StateMachineRightClickMenu(object):
                 save_as_library_sub_menu.append(create_menu_item(library_root_key, constants.SIGN_LIB,
                                                                  callback_function,
                                                                  accel_code=None, accel_group=accel_group))
-
+        menu.append(Gtk.SeparatorMenuItem())
+        callback_function = partial(self.on_change_background_color, state_model=selected_state_m)
+        menu.append(create_menu_item("Change Background Color",
+                                     constants.BUTTON_CHANGE_BACKGROUND_COLOR,
+                                     callback_function,
+                                     accel_group=accel_group))
         return menu
 
     def insert_show_library_content_in_menu(self, menu, shortcuts_dict, accel_group):
@@ -225,6 +227,14 @@ class StateMachineRightClickMenu(object):
                                                    self.on_run_to_selected_state_activate,
                                                    accel_code=shortcuts_dict['run_to_selected'][0],
                                                    accel_group=accel_group))
+        execution_sub_menu.append(create_menu_item("run this state", constants.BUTTON_RUN_SELECTED_STATE,
+                                                   self.on_run_selected_state_activate,
+                                                   accel_code=shortcuts_dict['run_selected'][0],
+                                                   accel_group=accel_group))
+        execution_sub_menu.append(create_menu_item("only run this state", constants.BUTTON_ONLY_RUN_SELECTED_STATE,
+                                                   self.on_run_only_selected_state_activate,
+                                                   accel_code=shortcuts_dict['only_run_selected'][0],
+                                                   accel_group=accel_group))
 
     def insert_copy_cut_paste_in_menu(self, menu, shortcuts_dict, accel_group, no_paste=False):
         menu.append(create_menu_item("Copy selection", constants.BUTTON_COPY, self.on_copy_activate,
@@ -275,11 +285,12 @@ class StateMachineRightClickMenu(object):
         if state_m is not None:
             gui_helper_state_machine.gui_helper_state.toggle_show_content_flag_of_library_state_model(state_m)
 
-
     def on_select_library_tree_element(widget, date=None, state_m=None):
         from rafcon.gui.singleton import main_window_controller
         library_tree_controller = main_window_controller.get_controller('library_controller')
         library_tree_controller.select_library_tree_element_of_library_state_model(state_m)
+        library_usages_tree_controller = main_window_controller.get_controller('library_usages_controller')
+        library_usages_tree_controller.select_library_tree_element_of_library_state_model(state_m)
 
     def on_toggle_is_start_state(self, widget, data=None):
         self.shortcut_manager.trigger_action("is_start_state", None, None)
@@ -308,18 +319,18 @@ class StateMachineRightClickMenu(object):
     def on_add_scoped_variable(self, widget=None, data=None):
         self.shortcut_manager.trigger_action('add_scoped_variable', None, None)
 
+    def on_delete(self, widget=None, data=None):
+        self.shortcut_manager.trigger_action('delete', None, None)
+
     def on_copy_activate(self, widget, data=None):
-        # logger.info("trigger default copy")
         active_sm_m = self.state_machine_manager_model.get_selected_state_machine_model()
         global_clipboard.copy(active_sm_m.selection)
 
     def on_paste_activate(self, widget, data=None):
-        # logger.info("trigger default paste")
         active_sm_m = self.state_machine_manager_model.get_selected_state_machine_model()
         global_clipboard.paste(active_sm_m.selection.get_selected_state())
 
     def on_cut_activate(self, widget, data=None):
-        # logger.info("trigger default cut")
         active_sm_m = self.state_machine_manager_model.get_selected_state_machine_model()
         global_clipboard.cut(active_sm_m.selection)
 
@@ -335,6 +346,12 @@ class StateMachineRightClickMenu(object):
     def on_run_to_selected_state_activate(self, widget, data=None):
         self.shortcut_manager.trigger_action('run_to_selected', None, None)
 
+    def on_run_selected_state_activate(self, widget, data=None):
+        self.shortcut_manager.trigger_action('run_selected', None, None)
+
+    def on_run_only_selected_state_activate(self, widget, data=None):
+        self.shortcut_manager.trigger_action('only_run_selected', None, None)
+
     @staticmethod
     def on_save_as_activate(widget, data=None, path=None, save_as_function=None):
         # workaround to set the initial path in the 'choose folder' dialog to the handed one
@@ -354,7 +371,7 @@ class StateMachineRightClickMenu(object):
             gui_singletons.global_runtime_config.set_config_value('LAST_PATH_OPEN_SAVE', old_last_path_open)
 
     @staticmethod
-    def on_open_library_state_separately_activate(widget, data=None):
+    def on_open_library_state_separately_activate(widget, data=None, cursor_position=None):
         gui_helper_state_machine.open_library_state_separately()
 
     def on_substitute_state_activate(self, widget, data=None):
@@ -371,10 +388,12 @@ class StateMachineRightClickMenu(object):
             gui_helper_state_machine.change_state_type_with_error_handling_and_logger_messages(selection.get_selected_state(),
                                                                                                target_class)
 
+    @staticmethod
+    def on_change_background_color(widget, data=None, state_model=None):
+        gui_helper_state_machine.change_background_color(state_model)
+
     def mouse_click(self, widget, event=None):
         from rafcon.gui.models.library_state import LibraryStateModel
-        # logger.info("Single right click -> selection is \n{0}"
-        #             "".format(gui_singletons.state_machine_manager_model.get_selected_state_machine_model().selection.get_all()))
         if event.type == Gdk.EventType.BUTTON_PRESS and event.get_button()[1] == 3:
             selection = gui_singletons.state_machine_manager_model.get_selected_state_machine_model().selection
             if len(selection) == 1 and len(selection.states) == 1 and \
@@ -386,7 +405,6 @@ class StateMachineRightClickMenu(object):
             return self.activate_menu(event, menu)
 
     def activate_menu(self, event, menu):
-        # logger.info("activate_menu by " + self.__class__.__name__)
         menu.popup(None, None, None, None, event.get_button()[1], event.time)
         return True
 
@@ -408,7 +426,6 @@ class StateMachineTreeRightClickMenuController(StateMachineRightClickMenuControl
         view.connect('button_press_event', self.mouse_click)
 
     def activate_menu(self, event, menu):
-        # logger.info("activate_menu by " + self.__class__.__name__)
         pthinfo = self.view.get_path_at_pos(int(event.x), int(event.y))
 
         if pthinfo is not None:
@@ -420,43 +437,12 @@ class StateMachineTreeRightClickMenuController(StateMachineRightClickMenuControl
         return True
 
 
-class StateRightClickMenuControllerOpenGLEditor(StateMachineRightClickMenuController):
-
-    def register_view(self, view):
-        ExtendedController.register_view(self, view)
-        from rafcon.gui.views.graphical_editor import GraphicalEditorView
-        assert isinstance(view, GraphicalEditorView)
-        view.editor.connect('button_press_event', self.mouse_click)
-
-    def activate_menu(self, event, menu):
-        # logger.info("activate_menu by " + self.__class__.__name__)
-        selection = gui_singletons.state_machine_manager_model.get_selected_state_machine_model().selection
-        if len(selection.states) > 0 or len(selection.scoped_variables) > 0:
-            menu.popup(None, None, None, None, event.get_button()[1], event.time)
-            return True
-        else:
-            return False
-
-    def on_copy_activate(self, widget, data=None):
-        # logger.info("trigger opengl copy")
-        self.shortcut_manager.trigger_action("copy", None, None)
-
-    def on_paste_activate(self, widget, data=None):
-        # logger.info("trigger opengl paste")
-        self.shortcut_manager.trigger_action("paste", None, None)
-
-    def on_cut_activate(self, widget, data=None):
-        # logger.info("trigger opengl cut")
-        self.shortcut_manager.trigger_action("cut", None, None)
-
-
 class StateRightClickMenuGaphas(StateMachineRightClickMenu):
     """ A class for handling the right click menu inside gaphas
 
     """
 
     def activate_menu(self, event, menu):
-        # logger.info("activate_menu by " + self.__class__.__name__)
         selection = gui_singletons.state_machine_manager_model.get_selected_state_machine_model().selection
         if len(selection.states) > 0 or len(selection.scoped_variables) > 0:
             from rafcon.gui.helpers.coordinates import screen2main_window
@@ -469,13 +455,10 @@ class StateRightClickMenuGaphas(StateMachineRightClickMenu):
             return False
 
     def on_copy_activate(self, widget, data=None):
-        # logger.info("trigger gaphas copy")
         self.shortcut_manager.trigger_action("copy", None, None)
 
     def on_paste_activate(self, widget, data=None):
-        # logger.info("trigger gaphas paste")
         self.shortcut_manager.trigger_action("paste", None, None, cursor_position=self.menu_position)
 
     def on_cut_activate(self, widget, data=None):
-        # logger.info("trigger gaphas cut")
         self.shortcut_manager.trigger_action("cut", None, None)
