@@ -21,7 +21,6 @@
 
 from gi.repository import GObject
 from gi.repository import Gtk
-from builtins import str
 
 from rafcon.core.state_elements.scope import ScopedVariable
 from rafcon.core.state_elements.data_port import InputDataPort, OutputDataPort
@@ -53,7 +52,6 @@ class StateDataFlowsListController(LinkageListController):
 
     ID_STORAGE_ID = 0
     FROM_STATE_STORAGE_ID = 1
-    FROM_KEY_STORAGE_ID = 2
     TO_STATE_STORAGE_ID = 3
     TO_KEY_STORAGE_ID = 4
     IS_EXTERNAL_STORAGE_ID = 5
@@ -81,7 +79,7 @@ class StateDataFlowsListController(LinkageListController):
         self.data_flow_dict = {'internal': {},
                                'external': {}}
         self.debug_log = False
-        super(StateDataFlowsListController, self).__init__(model, view, view.get_top_widget(), list_store, logger)
+        super(StateDataFlowsListController, self).__init__(model, view, view.get_parent_widget(), list_store, logger)
 
     def destroy(self):
         self.view['from_state_col'].set_cell_data_func(self.view['from_state_combo'], None)
@@ -138,7 +136,6 @@ class StateDataFlowsListController(LinkageListController):
         self.update(initiator='"register view"')
 
     def find_free_and_valid_data_flows(self, depend_to_state_id=None):
-        # print("\n internal from %s \n\n internal to %s" % (self.free_to_port_internal, self.from_port_internal))
         internal_data_flows = []
 
         def add_if_valid(future_data_flow_parent, from_port, to_port, data_flow_list):
@@ -165,22 +162,17 @@ class StateDataFlowsListController(LinkageListController):
 
         if self.free_to_port_internal and self.from_port_internal:
             for from_state_id, elems in self.from_port_internal.items():
-                # print("\n\nfrom_state %s and ports %s" % (from_state_id, [(elem.name, elem.data_type) for elem in elems]))
                 for from_port in elems:
-                    for to_state_id, elems in list(self.free_to_port_internal.items()):
-                        # print("\nto_state %s and ports %s" % (to_state_id, [(elem.name, elem.data_type) for elem in elems]))
+                    for to_state_id, elems in self.free_to_port_internal.items():
                         for to_port in elems:
                             if from_state_id == from_port.parent.state_id and to_state_id == to_port.parent.state_id:
                                 add_if_valid(self.model.state, from_port, to_port, internal_data_flows)
 
-        # print("\n\n\n" + 60*"-" + "\n external from %s \n\n external to %s" % (self.free_to_port_external, self.from_port_external))
         external_data_flows = []
         if self.free_to_port_external and self.from_port_external:
-            for from_state_id, elems in list(self.from_port_external.items()):
-                # print("\n\nfrom_state %s and ports %s" % (from_state_id, [(elem.name, elem.data_type) for elem in elems]))
+            for from_state_id, elems in self.from_port_external.items():
                 for from_port in elems:
-                    for to_state_id, elems in list(self.free_to_port_external.items()):
-                        # print("\nto_state %s and ports %s" % (to_state_id, [(elem.name, elem.data_type) for elem in elems]))
+                    for to_state_id, elems in self.free_to_port_external.items():
                         for to_port in elems:
                             if from_state_id == from_port.parent.state_id and to_state_id == to_port.parent.state_id:
                                 add_if_valid(self.model.state.parent, from_port, to_port, external_data_flows)
@@ -199,35 +191,23 @@ class StateDataFlowsListController(LinkageListController):
             return
         own_state_id = self.model.state.state_id
         [possible_internal_data_flows, possible_external_data_flows] = self.find_free_and_valid_data_flows(own_state_id)
-        # print("\n\npossible internal data_flows\n %s" % possible_internal_data_flows)
-        # print("\n\npossible external data_flows\n %s" % possible_external_data_flows)
-
-        from_key = None
         if self.view_dict['data_flows_internal'] and possible_internal_data_flows:
-            # print(self.from_port_internal)
             from_state_id = possible_internal_data_flows[0][0]
             from_key = possible_internal_data_flows[0][1]
-            # print(from_state_id, from_key, self.model.state.state_id)
             to_state_id = possible_internal_data_flows[0][2]
             to_key = possible_internal_data_flows[0][3]
-            # print("NEW DATA_FLOW INTERNAL IS: ", from_state_id, from_key, to_state_id, to_key)
             try:
-                data_flow_id = self.model.state.add_data_flow(from_state_id, from_key, to_state_id, to_key)
-                # print("NEW DATA_FLOW INTERNAL IS: ", self.model.state.data_flows[data_flow_id])
+                self.model.state.add_data_flow(from_state_id, from_key, to_state_id, to_key)
             except (AttributeError, ValueError) as e:
                 logger.error("Data Flow couldn't be added: {0}".format(e))
                 return
-        elif self.view_dict['data_flows_external'] and possible_external_data_flows:  # self.free_to_port_external:
+        elif self.view_dict['data_flows_external'] and possible_external_data_flows:
             from_state_id = possible_external_data_flows[0][0]
-            # print(from_state_id, self.model.state.output_data_ports)
             from_key = possible_external_data_flows[0][1]
             to_state_id = possible_external_data_flows[0][2]
             to_key = possible_external_data_flows[0][3]
-            # print("NEW DATA_FLOW EXTERNAL IS: ", from_state_id, from_key, to_state_id, to_key, \)
-            #     get_state_model(self.model.parent, to_state_id).state.get_data_port_by_id(to_key)
             try:
-                data_flow_id = self.model.parent.state.add_data_flow(from_state_id, from_key, to_state_id, to_key)
-                # print("NEW DATA_FLOW EXTERNAL IS: ", self.model.parent.state.data_flows[data_flow_id])
+                self.model.parent.state.add_data_flow(from_state_id, from_key, to_state_id, to_key)
             except (AttributeError, ValueError) as e:
                 logger.error("Data Flow couldn't be added: {0}".format(e))
                 return
@@ -351,15 +331,9 @@ class StateDataFlowsListController(LinkageListController):
         self.list_store.clear()
 
         if self.view_dict['data_flows_internal'] and isinstance(self.model, ContainerStateModel):
-            for data_flow in list(self.model.state.data_flows.values()):
-
-                # print("type: ", type(data_flow))
-                if data_flow.data_flow_id in list(self.data_flow_dict['internal'].keys()):
+            for data_flow in self.model.state.data_flows.values():
+                if data_flow.data_flow_id in self.data_flow_dict['internal'].keys():
                     df_dict = self.data_flow_dict['internal'][data_flow.data_flow_id]
-                    # TreeStore for: id, from-state, from-key, to-state, to-key, is_external,
-                    #       name-color, to-state-color, data-flow-object, state-object, is_editable
-                    # print('insert int: ', data_flow.data_flow_id, df_dict['from_state'], df_dict['from_key'], \)
-                    #     df_dict['to_state'], df_dict['to_key']
                     self.list_store.append([data_flow.data_flow_id,
                                             df_dict['from_state'],
                                             df_dict['from_key'],
@@ -370,14 +344,10 @@ class StateDataFlowsListController(LinkageListController):
                                             self.model.get_data_flow_m(data_flow.data_flow_id)])
 
         if self.view_dict['data_flows_external'] and not self.model.state.is_root_state:
-            for data_flow in list(self.model.parent.state.data_flows.values()):
+            for data_flow in self.model.parent.state.data_flows.values():
                 # data_flow = row[0]
-                if data_flow.data_flow_id in list(self.data_flow_dict['external'].keys()):
+                if data_flow.data_flow_id in self.data_flow_dict['external'].keys():
                     df_dict = self.data_flow_dict['external'][data_flow.data_flow_id]
-                    # TreeStore for: id, from-state, from-key, to-state, to-key, is_external,
-                    #       name-color, to-state-color, data-flow-object, state-object, is_editable
-                    # print('insert ext: ', data_flow.data_flow_id, df_dict['from_state'], df_dict['from_key'], \)
-                    #     df_dict['to_state'], df_dict['to_key']
                     self.list_store.append([data_flow.data_flow_id,
                                             df_dict['from_state'],
                                             df_dict['from_key'],
@@ -399,7 +369,6 @@ class StateDataFlowsListController(LinkageListController):
     @LinkageListController.observe("state", before=True)
     def before_notification_of_parent_or_state(self, model, prop_name, info):
         """ Set the no update flag to avoid updates in between of a state removal. """
-        # logger.info("before_notification_of_parent_or_state: {0}".format(NotificationOverview(info)))
         self.check_no_update_flags_and_return_combined_flag(prop_name, info)
 
     @LinkageListController.observe("state", after=True)
@@ -468,14 +437,13 @@ def get_key_combos(ports, keys_store, not_key=None):
                            str(not_key) + '.' +
                            (port.data_type.__name__ or 'None') + '.' +
                            port.name])
-    for key in list(ports.keys()):
+    for key in ports.keys():
         if not not_key == key:
             port = ports[key]
             keys_store.append([PORT_TYPE_TAG.get(type(port), 'None') + '.#' +
                                str(key) + '.' +
                                (port.data_type.__name__ or 'None') + '.' +
                                port.name])
-    # print("final store: ", keys_store)
     return keys_store
 
 
@@ -513,7 +481,7 @@ def update_data_flows(model, data_flow_dict, tree_dict_combos):
 
     # from_state, to_key, to_state, to_key, external
     if isinstance(model, ContainerStateModel):
-        for data_flow in list(model.state.data_flows.values()):  # model.data_flow_list_store:
+        for data_flow in model.state.data_flows.values():  # model.data_flow_list_store:
 
             # TREE STORE LABEL
             # check if from Self_state
@@ -525,7 +493,6 @@ def update_data_flows(model, data_flow_dict, tree_dict_combos):
                     from_state = take_from_dict(model.state.states, data_flow.from_state)
                     from_state_label = from_state.name + '.' + data_flow.from_state
                 else:
-                    # print(data_flow.from_state, data_flow.from_key, data_flow.to_state, data_flow.to_key)
                     logger.warning("DO break in ctrl/data_flow.py -1")
                     break
             # check if to Self_state
@@ -537,7 +504,6 @@ def update_data_flows(model, data_flow_dict, tree_dict_combos):
                     to_state = take_from_dict(model.state.states, data_flow.to_state)
                     to_state_label = to_state.name + '.' + data_flow.to_state
                 else:
-                    # print(data_flow.from_state, data_flow.from_key, data_flow.to_state, data_flow.to_key)
                     logger.warning("DO break in ctrl/data_flow.py 0")
                     break
 
@@ -549,7 +515,7 @@ def update_data_flows(model, data_flow_dict, tree_dict_combos):
                                  from_key_port.name
 
             to_key_port = to_state.get_data_port_by_id(data_flow.to_key)
-            # to_key_label = ''
+            to_key_label = ''
             if to_key_port is not None:
                 to_key_label = PORT_TYPE_TAG.get(type(to_key_port), 'None') + '.' + \
                                (to_key_port.data_type.__name__ or 'None') + '.' + \
@@ -567,7 +533,7 @@ def update_data_flows(model, data_flow_dict, tree_dict_combos):
                     to_states_store.append(['self.' + model.state.name + '.' + model.state.state_id])
                 if model.state.state_id in from_ports_internal or model.state.state_id == data_flow.from_state:
                     from_states_store.append(['self.' + model.state.name + '.' + model.state.state_id])
-                for state_model in list(model.states.values()):
+                for state_model in model.states.values():
                     if state_model.state.state_id in free_to_port_internal or \
                                     state_model.state.state_id == data_flow.to_state:
                         to_states_store.append([state_model.state.name + '.' + state_model.state.state_id])
@@ -577,10 +543,7 @@ def update_data_flows(model, data_flow_dict, tree_dict_combos):
 
             from_keys_store = Gtk.ListStore(GObject.TYPE_STRING)
             if model.state.state_id == data_flow.from_state:
-                # print("input_ports", model.state.input_data_ports)
-                # print(type(model))
                 if isinstance(model, ContainerStateModel):
-                    # print("scoped_variables", model.state.scoped_variables)
                     combined_ports = {}
                     combined_ports.update(model.state.scoped_variables)
                     combined_ports.update(model.state.input_data_ports)
@@ -588,16 +551,12 @@ def update_data_flows(model, data_flow_dict, tree_dict_combos):
                 else:
                     get_key_combos(model.state.input_data_ports, from_keys_store, data_flow.from_key)
             else:
-                # print("output_ports", model.states[data_flow.from_state].state.output_data_ports)
                 get_key_combos(model.state.states[data_flow.from_state].output_data_ports,
                                from_keys_store, data_flow.from_key)
 
             to_keys_store = Gtk.ListStore(GObject.TYPE_STRING)
             if model.state.state_id == data_flow.to_state:
-                # print("output_ports", model.state.output_data_ports)
-                # print(type(model))
                 if isinstance(model, ContainerStateModel):
-                    # print("scoped_variables", model.state.scoped_variables)
                     combined_ports = {}
                     combined_ports.update(model.state.scoped_variables)
                     combined_ports.update(model.state.output_data_ports)
@@ -605,17 +564,15 @@ def update_data_flows(model, data_flow_dict, tree_dict_combos):
                 else:
                     get_key_combos(model.state.output_data_ports, to_keys_store, data_flow.to_key)
             else:
-                # print("input_ports", model.states[data_flow.to_state].state.input_data_ports)
                 get_key_combos(model.state.states[data_flow.to_state].input_data_ports
                                , to_keys_store, data_flow.to_key)
             tree_dict_combos['internal'][data_flow.data_flow_id] = {'from_state': from_states_store,
                                                                     'from_key': from_keys_store,
                                                                     'to_state': to_states_store,
                                                                     'to_key': to_keys_store}
-            # print("internal", data_flow_dict['internal'][data_flow.data_flow_id])
 
     if not model.state.is_root_state:
-        for data_flow in list(model.parent.state.data_flows.values()):  # model.parent.data_flow_list_store:
+        for data_flow in model.parent.state.data_flows.values():  # model.parent.data_flow_list_store:
 
             # TREE STORE LABEL
             # check if from Self_state
@@ -631,7 +588,6 @@ def update_data_flows(model, data_flow_dict, tree_dict_combos):
                         from_state = take_from_dict(model.parent.state.states, data_flow.from_state)
                         from_state_label = from_state.name + '.' + data_flow.from_state
                     else:
-                        # print("#", data_flow.from_state, data_flow.from_key, data_flow.to_state, data_flow.to_key)
                         logger.warning("DO break in ctrl/data_flow.py 1")
                         break
 
@@ -648,7 +604,6 @@ def update_data_flows(model, data_flow_dict, tree_dict_combos):
                         to_state = take_from_dict(model.parent.state.states, data_flow.to_state)
                         to_state_label = to_state.name + '.' + data_flow.to_state
                     else:
-                        # print("##", data_flow.from_state, data_flow.from_key, data_flow.to_state, data_flow.to_key)
                         logger.warning("DO break in ctrl/data_flow.py 2")
                         break
             if model.state.state_id in [data_flow.from_state, data_flow.to_state]:
@@ -674,7 +629,7 @@ def update_data_flows(model, data_flow_dict, tree_dict_combos):
 
                 # only self-state
                 from_states_store = Gtk.ListStore(GObject.TYPE_STRING)
-                for state_id in list(from_ports_external.keys()):
+                for state_id in from_ports_external.keys():
                     if model.parent.state.state_id == state_id:
                         state_model = model.parent
                     else:
@@ -688,12 +643,11 @@ def update_data_flows(model, data_flow_dict, tree_dict_combos):
                 # only outports of self
                 from_keys_store = Gtk.ListStore(GObject.TYPE_STRING)
                 if model.parent.state.state_id == data_flow.from_state:
-                    # print("output_ports", model.parent.states[data_flow.from_state].state.output_data_ports)
                     combined_ports = {}
                     combined_ports.update(model.parent.state.input_data_ports)
                     combined_ports.update(model.parent.state.scoped_variables)
                     get_key_combos(combined_ports, from_keys_store, data_flow.to_key)
-                elif data_flow.from_state in [state_m.state.state_id for state_m in list(model.parent.states.values())]:
+                elif data_flow.from_state in [state_m.state.state_id for state_m in model.parent.states.values()]:
                     get_key_combos(model.parent.state.states[data_flow.from_state].output_data_ports,
                                    from_keys_store, data_flow.to_key)
                 else:
@@ -702,7 +656,7 @@ def update_data_flows(model, data_flow_dict, tree_dict_combos):
 
                 # all states and parent-state
                 to_states_store = Gtk.ListStore(GObject.TYPE_STRING)
-                for state_id in list(free_to_port_external.keys()):
+                for state_id in free_to_port_external.keys():
                     if model.parent.state.state_id == state_id:
                         state_model = model.parent
                     else:
@@ -727,7 +681,7 @@ def update_data_flows(model, data_flow_dict, tree_dict_combos):
                                           act_to_key_port.name])
 
                     # second all other possible ones
-                    if to_state_model.state is model.state.parent:
+                    if to_state_model.state is model.state.parent:#
                         possible_port_ids = list(to_state_model.state.output_data_ports.keys()) + list(to_state_model.state.scoped_variables.keys())
                     else:
                         possible_port_ids = list(to_state_model.state.input_data_ports.keys())
@@ -745,10 +699,6 @@ def update_data_flows(model, data_flow_dict, tree_dict_combos):
                                                                         'from_key': from_keys_store,
                                                                         'to_state': to_states_store,
                                                                         'to_key': to_keys_store}
-                # print("external", data_flow_dict['external'][data_flow.data_flow_id])
-
-    # print("ALL SCANNED: ", data_flow_dict['internal'].keys(), data_flow_dict['external'].keys(), \)
-    #     tree_dict_combos['internal'].keys(), tree_dict_combos['external'].keys()
     return free_to_port_internal, free_to_port_external, from_ports_internal, from_ports_external
 
 
@@ -766,18 +716,10 @@ def find_free_keys(model):
         container_from_ports.extend(list(model.state.scoped_variables.values()))
         container_from_ports.extend(list(model.state.input_data_ports.values()))
         # free_container_ports.extend(model.state.scoped_variables.keys())
-        nfree_container_ports.extend([s.name for s in list(model.state.scoped_variables.values())])
+        nfree_container_ports.extend([s.name for s in model.state.scoped_variables.values()])
         if model.state.output_data_ports:
-            port_keys = list(model.state.output_data_ports.keys())
-            # print("actual keys: ", port_keys)
-            # TODO check if the filter can be made valid -> at the moment it is not fully valid because multiple data-flows  for IO are allowed
-            # for data_flow in model.state.data_flows.values():
-            #     port_keys = [port_id for port_id in port_keys if not (model.state.state_id == data_flow.to_state and port_id == data_flow.to_key)]
-
-                # print("actual keys: ", port_keys)
-            # print("found free prots: ", port_keys)
+            port_keys = model.state.output_data_ports.keys()
             free_container_ports.extend([model.state.output_data_ports[i] for i in port_keys])
-            # free_container_ports.extend(port_keys)
             nfree_container_ports.extend([model.state.output_data_ports[i].name for i in port_keys])
 
         if free_container_ports:
@@ -787,27 +729,17 @@ def find_free_keys(model):
             from_ports[model.state.state_id] = container_from_ports
 
         # check every single state
-        for state_model in list(model.states.values()):
+        for state_model in model.states.values():
             if state_model.state.output_data_ports:
                 from_ports[state_model.state.state_id] = list(state_model.state.output_data_ports.values())
 
             if state_model.state.input_data_ports:
-                port_keys = list(state_model.state.input_data_ports.keys())
-                # print("actual keys: ", port_keys)
-                # TODO check if the filter can be made valid -> at the moment it is not fully valid because multiple data-flows  for IO are allowed
-                # for data_flow in model.state.data_flows.values():
-                #     port_keys = [port_id for port_id in port_keys if not (state_model.state.state_id == data_flow.to_state and port_id == data_flow.to_key)]
-                    # print("actual keys: ", port_keys)
-
-                # print("found free prots: ", port_keys)
+                port_keys = state_model.state.input_data_ports.keys()
                 if port_keys:
                     free_to_ports[state_model.state.state_id] = [state_model.state.input_data_ports[i] for i in
                                                                  port_keys]
                     nfree_to_ports[state_model.state.name] = [state_model.state.input_data_ports[i].name for i in
                                                               port_keys]
-
-    # print("\nFOUND FREE PORTS: \n", nfree_to_ports, "\n", free_to_ports, "\n",  from_ports)
-
     return free_to_ports, from_ports
 
 
