@@ -10,13 +10,12 @@
 # Rico Belder <rico.belder@dlr.de>
 # Sebastian Brunner <sebastian.brunner@dlr.de>
 
-from builtins import str
 import os.path
 from copy import copy, deepcopy
 from weakref import ref
-from gtkmvc3.model_mt import ModelMT
-from gtkmvc3.observable import Signal
-import gtkmvc3.support.wrappers as wrappers
+from rafcon.design_patterns.mvc.model import ModelMT
+from rafcon.design_patterns.observer.observable import Signal
+import rafcon.design_patterns.observer.wrappers as wrappers
 
 from rafcon.gui.models.signals import MetaSignalMsg, Notification
 from rafcon.gui.models.meta import MetaModel
@@ -127,15 +126,13 @@ class AbstractStateModel(MetaModel, Hashable):
         if self.meta != other.meta:
             return False
         for attr in self.state.state_element_attrs:
-            # some state element attributes are wrapped in a wrappers.ObsWrapperBase class, some of which are held in
-            # lists or dicts. Those need to be compared element-wise.
             my_attr = getattr(self, attr)
             other_attr = getattr(other, attr)
-            if isinstance(my_attr, wrappers.ObsSeqWrapper):
-                if isinstance(my_attr, wrappers.ObsListWrapper):  # elements are stored in a list
+            if isinstance(my_attr, wrappers.IterableWrapper):
+                if isinstance(my_attr, wrappers.ListWrapper):
                     elements = my_attr
                     other_elements = other_attr
-                elif isinstance(my_attr, wrappers.ObsMapWrapper):  # elements are stored in a dict
+                elif isinstance(my_attr, wrappers.DictWrapper):
                     elements = my_attr.items()
                     other_elements = other_attr.items()
                 else:
@@ -382,24 +379,15 @@ class AbstractStateModel(MetaModel, Hashable):
         """This method notifies the parent state and child state models about complex actions
         """
         msg = info.arg
-        # print("action_signal_triggered state: ", self.state.state_id, model, prop_name, info)
         if msg.action.startswith('sm_notification_'):
             return
-        # # affected child propagation from state
-        # if hasattr(self, 'states'):
-        #     for m in info['arg'].affected_models:
-        #         print(m, self.states)
-        #         print([m is mm for mm in self.states.values()], [m in self for m in info['arg'].affected_models], \)
-        #             [m in self.states.values() for m in info['arg'].affected_models]
         if any([m in self for m in info['arg'].affected_models]):
             if not msg.action.startswith('parent_notification_'):
                 new_msg = msg._replace(action='parent_notification_' + msg.action)
             else:
                 new_msg = msg
             for m in info['arg'].affected_models:
-                # print('???propagate it to', m, m.parent)
                 if isinstance(m, AbstractStateModel) and m in self:
-                    # print('!!!propagate it from {0} to {1} {2}'.format(self.state.state_id, m.state.state_id, m))
                     m.action_signal.emit(new_msg)
 
         if msg.action.startswith('parent_notification_'):
@@ -409,49 +397,35 @@ class AbstractStateModel(MetaModel, Hashable):
         if self.parent is not None:
             # Notify parent about change of meta data
             info.arg = msg
-            # print("DONE1", self.state.state_id, msg)
             self.parent.action_signal_triggered(model, prop_name, info)
-            # print("FINISH DONE1", self.state.state_id, msg)
         # state machine propagation of action signal (indirect) TODO remove finally
         elif not msg.action.startswith('sm_notification_'):  # Prevent recursive call
             # If we are the root state, inform the state machine model by emitting our own meta signal.
             # To make the signal distinguishable for a change of meta data to our state, the change property of
             # the message is prepended with 'sm_notification_'
-            # print("DONE2", self.state.state_id, msg)
             new_msg = msg._replace(action='sm_notification_' + msg.action)
             self.action_signal.emit(new_msg)
-            # print("FINISH DONE2", self.state.state_id, msg)
-        else:
-            # print("DONE3 NOTHING")
-            pass
 
     @ModelMT.observe("meta_signal", signal=True)
     def meta_changed(self, model, prop_name, info):
         """This method notifies the parent state about changes made to the meta data
         """
         msg = info.arg
-        # print("meta_changed state: ", model, prop_name, info)
         if msg.notification is None:
             # Meta data of this state was changed, add information about notification to the signal message
             notification = Notification(model, prop_name, info)
             msg = msg._replace(notification=notification)
-            # print("DONE0 ", msg)
 
         if self.parent is not None:
             # Notify parent about change of meta data
             info.arg = msg
             self.parent.meta_changed(model, prop_name, info)
-            # print("DONE1 ", msg)
         elif not msg.change.startswith('sm_notification_'):  # Prevent recursive call
             # If we are the root state, inform the state machine model by emitting our own meta signal.
             # To make the signal distinguishable for a change of meta data to our state, the change property of
             # the message is prepended with 'sm_notification_'
             msg = msg._replace(change='sm_notification_' + msg.change)
             self.meta_signal.emit(msg)
-            # print("DONE2 ", msg)
-        else:
-            # print("DONE3 NOTHING")
-            pass
 
     # ---------------------------------------- meta data methods ---------------------------------------------
 
@@ -470,32 +444,15 @@ class AbstractStateModel(MetaModel, Hashable):
         :return: if meta data file was loaded True otherwise False
         :rtype: bool
         """
-        # TODO: for an Execution state this method is called for each hierarchy level again and again, still?? check it!
-        # print("1AbstractState_load_meta_data: ", path, not path)
         if not path:
             path = self.state.file_system_path
-        # print("2AbstractState_load_meta_data: ", path)
         if path is None:
             self.meta = Vividict({})
             return False
         path_meta_data = os.path.join(path, storage.FILE_NAME_META_DATA)
-
-        # TODO: Should be removed with next minor release
-        if not os.path.exists(path_meta_data):
-            logger.debug("Because meta data was not found in {0} use backup option {1}"
-                         "".format(path_meta_data, os.path.join(path, storage.FILE_NAME_META_DATA_OLD)))
-            path_meta_data = os.path.join(path, storage.FILE_NAME_META_DATA_OLD)
-            # TODO use the following logger message to debug meta data load process and to avoid maybe repetitive loads
-            # if not os.path.exists(path_meta_data):
-            #     logger.info("path not found {0}".format(path_meta_data))
-
         try:
-            # print("try to load meta data from {0} for state {1}".format(path_meta_data, self.state))
             tmp_meta = storage.load_data_file(path_meta_data)
         except ValueError as e:
-            # if no element which is newly generated log a warning
-            # if os.path.exists(os.path.dirname(path)):
-            #     logger.debug("Because '{1}' meta data of {0} was not loaded properly.".format(self, e))
             if not path.startswith(constants.RAFCON_TEMP_PATH_STORAGE) and not os.path.exists(os.path.dirname(path)):
                 logger.debug("Because '{1}' meta data of {0} was not loaded properly.".format(self, e))
             tmp_meta = {}
@@ -510,7 +467,6 @@ class AbstractStateModel(MetaModel, Hashable):
             self.meta_signal.emit(MetaSignalMsg("load_meta_data", "all", True))
             return True
         else:
-            # print("nothing to parse", tmp_meta)
             return False
 
     def store_meta_data(self, copy_path=None):
@@ -572,7 +528,6 @@ class AbstractStateModel(MetaModel, Hashable):
 
         :param meta_data: Dictionary of loaded meta data
         """
-        # print("_parse meta data", meta_data)
         for data_port_m in self.input_data_ports:
             self._copy_element_meta_data_from_meta_file_data(meta_data, data_port_m, "input_data_port",
                                                              data_port_m.data_port.data_port_id)
@@ -606,7 +561,6 @@ class AbstractStateModel(MetaModel, Hashable):
         """
         meta_data_element_id = element_name + str(element_id)
         meta_data_element = meta_data[meta_data_element_id]
-        # print(meta_data_element_id, element_m, meta_data_element)
         element_m.meta = meta_data_element
         del meta_data[meta_data_element_id]
 
