@@ -10,8 +10,8 @@
 # Rico Belder <rico.belder@dlr.de>
 # Sebastian Brunner <sebastian.brunner@dlr.de>
 
-from gtkmvc3.model_mt import ModelMT
-
+from rafcon.design_patterns.singleton import Singleton
+from rafcon.design_patterns.mvc.model import ModelMT
 from rafcon.core.execution.execution_engine import ExecutionEngine
 
 from rafcon.utils.vividict import Vividict
@@ -20,11 +20,11 @@ from rafcon.utils import log
 logger = log.get_logger(__name__)
 
 
+@Singleton
 class StateMachineExecutionEngineModel(ModelMT):
 
     execution_engine = None
 
-    __sm_execution_engine_counter = 0
     __observables__ = ("execution_engine", )
 
     def __init__(self, execution_engine, meta=None):
