@@ -13,12 +13,9 @@
 # Rico Belder <rico.belder@dlr.de>
 # Sebastian Brunner <sebastian.brunner@dlr.de>
 
-from builtins import object
-from builtins import str
 from weakref import ref
 from gi.repository.Pango import SCALE, FontDescription
 from gi.repository import PangoCairo
-# from cairo import Antialias
 
 from gaphas.state import observed
 from gaphas.connector import Handle
@@ -54,21 +51,15 @@ class PortView(object):
         self.side = side
         self._parent = ref(parent)
         self._view = None
-
         self.text_color = gui_config.gtk_colors['LABEL']
         self.fill_color = gui_config.gtk_colors['LABEL']
-
         self._incoming_handles = []
         self._outgoing_handles = []
         self._connected_connections = []
         self._tmp_incoming_connected = False
         self._tmp_outgoing_connected = False
-
         self._name = name
-
-
         self.label_print_inside = True
-
         self._port_image_cache = ImageCache()
         self._label_image_cache = ImageCache()
         self._last_label_size = self.port_side_size, self.port_side_size
@@ -138,10 +129,6 @@ class PortView(object):
     def handle_pos(self):
         return self.handle.pos
 
-    @property
-    def port_pos(self):
-        return self.port.point
-
     @property
     def port_size(self):
         return self.port_side_size / 1.5, self.port_side_size
@@ -155,9 +142,6 @@ class PortView(object):
     def has_outgoing_connection(self):
         return len(self._outgoing_handles) > 0
 
-    def has_incoming_connection(self):
-        return len(self._incoming_handles) > 0
-
     def add_connected_handle(self, handle, connection_view, moving=False):
         from rafcon.gui.mygaphas.items.connection import ConnectionView
         assert isinstance(handle, Handle)
@@ -286,12 +270,10 @@ class PortView(object):
 
         # The parameters for drawing haven't changed, thus we can just copy the content from the last rendering result
         if from_cache:
-            # print("from cache")
             self._port_image_cache.copy_image_to_context(c, upper_left_corner)
 
         # Parameters have changed or nothing in cache => redraw
         elif not context.draw_all:
-            # print("draw")
             c = self._port_image_cache.get_context_for_image(current_zoom)
 
             c.move_to(0, 0)
@@ -342,13 +324,10 @@ class PortView(object):
                                                                            current_zoom, parameters)
         # The parameters for drawing haven't changed, thus we can just copy the content from the last rendering result
         if from_cache:
-            # print("draw port name from cache")
             self._label_image_cache.copy_image_to_context(c, upper_left_corner)
 
         # Parameters have changed or nothing in cache => redraw
         else:
-            # print("draw port name")
-
             # First we have to do a "dry run", in order to determine the size of the new label
             c.move_to(position.x.value, position.y.value)
             extents = gap_draw_helper.draw_port_label(c, self, transparency, False, label_position,
@@ -358,10 +337,6 @@ class PortView(object):
             label_pos = extents[0], extents[1]
             relative_pos = label_pos[0] - position[0], label_pos[1] - position[1]
             label_size = extents[2] - extents[0], extents[3] - extents[1]
-
-            # print(label_size[0], self.name, self.parent.model.state.name)
-            # if label_size[0] < constants.MINIMUM_PORT_NAME_SIZE_FOR_DISPLAY and self.parent:
-            #     return
             self._last_label_relative_pos = relative_pos
             self._last_label_size = label_size
 
@@ -376,10 +351,7 @@ class PortView(object):
                 # Copy image surface to current cairo context
                 upper_left_corner = (position[0] + relative_pos[0], position[1] + relative_pos[1])
                 self._label_image_cache.copy_image_to_context(context.cairo, upper_left_corner, zoom=current_zoom)
-
-                   # draw_all means, the bounding box of the state is calculated
-                   # As we are using drawing operation, not supported by Gaphas, we manually need to update the bounding box
-            else:  # context.draw_all:
+            else:
                 from gaphas.geometry import Rectangle
                 view = self.parent.canvas.get_first_view()
                 abs_pos = view.get_matrix_i2v(self.parent).transform_point(*label_pos)
@@ -788,7 +760,6 @@ class ScopedVariablePortView(PortView):
         cairo_context = c
         if isinstance(c, CairoBoundingBoxContext):
             cairo_context = c._cairo
-        # c.set_antialias(Antialias.GOOD)
 
         side_length = self.port_side_size
 
