@@ -10,7 +10,7 @@
 # Matthias Buettner <matthias.buettner@dlr.de>
 # Sebastian Brunner <sebastian.brunner@dlr.de>
 
-from gtkmvc3.view import View
+from rafcon.design_patterns.mvc.view import View
 
 from rafcon.gui import glade
 from rafcon.gui.utils import constants
@@ -18,16 +18,11 @@ from rafcon.gui.helpers import label
 
 
 class GlobalVariableEditorView(View):
-    builder = glade.get_glade_path("global_variable_editor_widget.glade")
-    top = 'global_variable_vbox'
-
     def __init__(self):
-        View.__init__(self)
-
+        super().__init__(builder_filename=glade.get_glade_path('global_variable_editor_widget.glade'), parent='global_variable_vbox')
         self['new_global_variable_button'].set_border_width(constants.BUTTON_BORDER_WIDTH)
         self['delete_global_variable_button'].set_border_width(constants.BUTTON_BORDER_WIDTH)
         self['lock_global_variable_button'].set_border_width(constants.BUTTON_BORDER_WIDTH)
         self['unlock_global_variable_button'].set_border_width(constants.BUTTON_BORDER_WIDTH)
         self.scrollbar_widget = self['scroller']
-
         label.ellipsize_labels_recursively(self['global_variables_toolbar'])
