@@ -11,8 +11,7 @@
 # Sebastian Brunner <sebastian.brunner@dlr.de>
 
 from gi.repository import Gtk
-from gtkmvc3.view import View
-from builtins import str
+from rafcon.design_patterns.mvc.view import View
 
 from rafcon.utils import log
 
@@ -21,7 +20,7 @@ logger = log.get_logger(__name__)
 
 class SingleWidgetWindowView(View):
     def __init__(self, view_class, width=500, height=500, title=None, pos=None):
-        View.__init__(self)
+        super().__init__(parent='main_frame')
 
         w = Gtk.Window()
         if title is None:
@@ -32,11 +31,9 @@ class SingleWidgetWindowView(View):
         if pos is not None:
             w.set_position(pos)
         self.widget_view = view_class()
-        w.add(self.widget_view.get_top_widget())
+        w.add(self.widget_view.get_parent_widget())
         w.show_all()
 
         self['main_frame'] = self.widget_view
         self.top = 'main_frame'
         self['main_window'] = w
-
-    pass  # class end
